@@ -14,6 +14,7 @@ from .base_client import AiriaBaseClient
 from .conversations import Conversations
 from .data_vector_search import DataVectorSearch
 from .deployments import Deployments
+from .library import Library
 from .pipeline_execution import PipelineExecution
 from .pipelines_config import PipelinesConfig
 from .project import Project
@@ -68,6 +69,7 @@ class AiriaClient(AiriaBaseClient):
         self.store = Store(self._request_handler)
         self.deployments = Deployments(self._request_handler)
         self.data_vector_search = DataVectorSearch(self._request_handler)
+        self.library = Library(self._request_handler)
 
     @classmethod
     def with_openai_gateway(
